@@ -78,7 +78,7 @@ class MarketAnalyzer:
     green_red = sns.diverging_palette(17, 170, n=5, l=70, as_cmap=True)
     red_green = sns.diverging_palette(170, 17, n=5, l=70, as_cmap=True)
 
-    def __init__(self, data, base=100.):
+    def __init__(self, data, base=100., hourlyze = False):
         """ Initialize object. """
         # Set data attribute
         self.base = base
@@ -93,7 +93,7 @@ class MarketAnalyzer:
         # TODO : available_metrics
         self.set_metric('annual_return', 'annual_volatility', 'sharpe',
                         'calmar', 'mdd')#, 'z_score')
-
+        self.hourlyze = hourlyze
     def _set_days_per_year(self):
         # Compute the average of days per year
         self.n_day_per_year = int(
@@ -231,6 +231,19 @@ class MarketAnalyzer:
             Table of key performance indicators.
 
         """
+        def filter_daily(dataframe):
+            dataframe['hour']=dataframe.index.hour
+            dataframe=dataframe[dataframe['hour']==0]
+            dataframe = dataframe.drop(columns = ['hour'])
+            return dataframe
+
+
+        comp_df = None
+        if self.hourlyze:
+            comp_df = filter_daily(self.df.copy())
+        else :
+            comp_df = self.df.copy()
+
         results = np.zeros([self.m, self.n])
         # df = self.get_perf()
 
@@ -240,12 +253,12 @@ class MarketAnalyzer:
             f, p = (self.parser_metrics[m][k] for k in ['f', 'p'])
             if 'lags' in p.keys():
                 # print(p)
-                p['lags'] = min(63, max(self.df.shape[0] - 1, 1))
+                p['lags'] = min(63, max(comp_df.shape[0] - 1, 1))
                 # print(p)
 
             for a in self.assets:
                 try:
-                    results[i, j] = f((getattr(self.df, a).values), **p)
+                    results[i, j] = f((getattr(comp_df, a).values), **p)
                     j += 1
                 except Exception as inst:
                     print(inst)
