@@ -44,16 +44,18 @@ def pair_trading_shifted_correlation(pair_df = None, correlation_range = 100, va
     correlation_dico = {}
     for shift in range(correlation_range):
         shifted_df = return_pair_df.shift(shift).copy()
-        shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
+        shifted_df['return' + suffixes[0]] = return_pair_df['return'+suffixes[0]].shift(shift)
         correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
     lag = max(correlation_dico, key=correlation_dico.get)
     if variant == 'a':
-        signal = return_pair_df['return' + suffixes[1]].values[-lag]
-        return -np.sign(signal), np.sign(signal)
+        signal = return_pair_df['return' + suffixes[0]].values[-lag]
+        # return -np.sign(signal), np.sign(signal)
+        return 0, np.sign(signal)
 
     elif variant == 'b':
-        signal = np.mean(return_pair_df['return' + suffixes[1]].values[-lag:])
-        return np.sign(signal), -np.sign(signal)
+        signal = np.mean(return_pair_df['return' + suffixes[0]].values[-lag:])
+        # return np.sign(signal), -np.sign(signal)
+        return 0, -np.sign(signal)
 
 def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlation_range = 100, risk = 10, alpha = 0.05, variant = 'a', suffixes=('_btc', '_eth'), **kwargs):
     len_histo = len(pair_df)
@@ -67,18 +69,19 @@ def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlat
         correlation_dico = {}
         for shift in range(correlation_range):
             shifted_df = return_pair_df.shift(shift).copy()
-            shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
+            shifted_df['return' + suffixes[0]] = return_pair_df['return'+suffixes[0]].shift(shift)
             correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
         lag = max(correlation_dico, key=correlation_dico.get)
 
         if variant == 'a':
-            signal = return_pair_df['return'+suffixes[1]].values[-lag]
-            return -np.sign(signal), np.sign(signal)
+            signal = return_pair_df['return'+suffixes[0]].values[-lag]
+            # return -np.sign(signal), np.sign(signal)
+            return 0, np.sign(signal)
 
         elif variant == 'b':
-            signal = np.mean(return_pair_df['return'+suffixes[1]].values[-lag:])
-            return np.sign(signal), -np.sign(signal)
-
+            signal = np.mean(return_pair_df['return'+suffixes[0]].values[-lag:])
+            # return np.sign(signal), -np.sign(signal)
+            return 0, -np.sign(signal)
     else:
         return np.nan,np.nan
 
