@@ -297,7 +297,10 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         dataframe = dataframe.sort_values(by=['time'])
         dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
         dataframe = dataframe.set_index(dataframe['date'])
-        dataframe = dataframe.drop(columns=['date'])
+        dataframe = dataframe.drop(columns=['date','volumefrom', 'conversionType', 'conversionSymbol' ])
+
+        dataframe = dataframe.rename(columns ={'volumeto':'volume'})
+
         print('size fetched')
         print(dataframe.shape)
         dataframe = dataframe[dataframe.index >= daily_crypto_starting_day]
