@@ -2,6 +2,11 @@ from plotly.subplots import make_subplots
 import plotly.graph_objs as go
 import plotly.graph_objects as go
 
+import plotly.express as px
+from itertools import cycle
+palette = cycle(px.colors.qualitative.Plotly)
+
+
 def create_ohlc_figure(data_df, underlying):
     fig = go.Figure(data=go.Ohlc(x=data_df.index,
                                  open=data_df['open'],
@@ -102,6 +107,10 @@ def plot_regime_close(data_df):
 
 
 def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strategy performances', height=600 ,width=1600):
+    palette = cycle(px.colors.qualitative.Bold)
+#    palette = cycle(px.colors.qualitative.Vivid)
+#    palette = cycle(px.colors.qualitative.Safe)
+
     if split:
         fig = make_subplots(rows=1, cols=len(data_df.columns))
         constituents = [col for col in data_df.columns if col not in ['date','Date']]
@@ -111,7 +120,11 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
                 x=data_df.index,
                 y=data_df[me_constituent],
                 name=me_constituent,
-                opacity=0.8)
+                opacity=0.8,
+                text=me_constituent,
+                hoverinfo='text',
+                marker_color=next(palette)
+            )
             fig.append_trace(trace_sig, row=1, col=counter)
             if logy:
                 fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=counter)
@@ -119,6 +132,8 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
 
         fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
         fig.update_xaxes(rangeslider_visible=True)
+
+
         return fig
     else:
         fig = make_subplots(rows=1, cols=1)
@@ -128,13 +143,18 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
                 x=data_df.index,
                 y=data_df[me_constituent],
                 name=me_constituent,
-                opacity=0.8)
+                opacity=0.8,
+                text=me_constituent,
+                hoverinfo='text',
+                marker_color=next(palette)
+            )
             fig.append_trace(trace_sig, row=1, col=1)
 
         if logy:
             fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=1)
         fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
         fig.update_xaxes(rangeslider_visible=True)
+
         return fig
 
 def plot_multiple_turnover(data_df, ma = None):
