@@ -60,17 +60,17 @@ def lo_slope_ma(data = None, pente_window = 7, contravariant = -1., **kwargs):
         return 0
 
 def alpha_2(data = None,  contravariant = -1., **kwargs):
-    data['log_vol'] = np.log(data['volumefrom'])
+    data['log_vol'] = np.log(data['volume'])
     correlation_coefficient = compute_correlation(data.log_vol.diff(2).rank(pct=True), (data.close - data.open)/data.open)
     return contravariant*correlation_coefficient
 
 def alpha_3(data = None, contravariant = -1., **kwargs):
-    correlation_coefficient = compute_correlation(data.open.rank(pct = True), data.volumefrom.rank(pct = True))
+    correlation_coefficient = compute_correlation(data.open.rank(pct = True), data.volume.rank(pct = True))
     return contravariant*correlation_coefficient
 
 def alpha_5(data = None, contravariant = -1., **kwargs):
-    data['volu_close'] = data['volumefrom']*data['close']
-    vwap = data['volu_close'].sum() / data['volumefrom'].sum()
+    data['volu_close'] = data['volume']*data['close']
+    vwap = data['volu_close'].sum() / data['volume'].sum()
     data['open_minus_vwap'] = data.open - vwap
     data['close_minus_vwap'] = data.close - vwap
     correlation_coefficient = compute_correlation(data['open_minus_vwap'].rank(pct = True), data['close_minus_vwap'].rank(pct = True))
@@ -85,11 +85,11 @@ def alpha_5_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume)
     data['aggregated_high'] =  data['aggregated_indice'].map(high)
     data['aggregated_low'] =  data['aggregated_indice'].map(low)
 
@@ -141,11 +141,11 @@ def alpha_5_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, *
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -197,11 +197,11 @@ def alpha_6_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -238,11 +238,11 @@ def alpha_6_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, *
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -286,11 +286,11 @@ def alpha_6_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, *
     else :
         return np.nan
 def alpha_6(data = None, contravariant = -1., **kwargs):
-    correlation_coefficient = compute_correlation(data['open'], data['volumefrom'])
+    correlation_coefficient = compute_correlation(data['open'], data['volume'])
     return contravariant*correlation_coefficient
 
 def alpha_6_rank(data = None, contravariant = -1., **kwargs):
-    correlation_coefficient = compute_correlation(data['open'].rank(pct = True), data['volumefrom'].rank(pct = True))
+    correlation_coefficient = compute_correlation(data['open'].rank(pct = True), data['volume'].rank(pct = True))
     return contravariant*correlation_coefficient
 
 def alpha_8(data = None, contravariant = -1 , lag=5, **kwargs):
@@ -302,11 +302,11 @@ def alpha_8(data = None, contravariant = -1 , lag=5, **kwargs):
 
 # Alpha  # 12: (sign(delta(volume, 1)) * (-1 * delta(close, 1)))
 def alpha_12(data = None, contravariant = -1., **kwargs):
-    signals = np.sign(data['volumefrom'].diff() * data['close'].diff())
+    signals = np.sign(data['volume'].diff() * data['close'].diff())
     return signals[-1]*contravariant
 
 def alpha_13(data = None, contravariant = -1., lag = 5,  **kwargs):
-    to_roll =  data[['close','volumefrom']]
+    to_roll =  data[['close','volume']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.dropna()
@@ -315,7 +315,7 @@ def alpha_13(data = None, contravariant = -1., lag = 5,  **kwargs):
 
 #Alpha#14: ((-1 * rank(delta(returns, 3))) * correlation(open, volume, 10))
 def alpha_14(data = None, contravariant = -1., lag = 3, **kwargs):
-    correlation_coefficient = compute_correlation(data['open'],data['volumefrom'])
+    correlation_coefficient = compute_correlation(data['open'],data['volume'])
     returns = data['close'].pct_change().diff(lag)
     returns=returns.to_frame()
     return returns.iloc[-1,0]*correlation_coefficient*contravariant
@@ -323,7 +323,7 @@ def alpha_14(data = None, contravariant = -1., lag = 3, **kwargs):
 # Alpha#15: (-1 * sum(rank(correlation(rank(high), rank(volume), 3)), 3))
 def alpha_15(data = None, contravariant = -1., lag = 3, **kwargs):
     data['high_rank'] = data['high'].rank(pct=True)
-    data['volume_rank'] = data['volumefrom'].rank(pct=True)
+    data['volume_rank'] = data['volume'].rank(pct=True)
     to_roll =  data[['high_rank','volume_rank']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
@@ -334,7 +334,7 @@ def alpha_15(data = None, contravariant = -1., lag = 3, **kwargs):
 # #Alpha#16: (-1 * rank(covariance(rank(high), rank(volume), 5)))
 def alpha_16(data = None, lag = 5, **kwargs):
     data['high_rank'] = data['high'].rank(pct=True)
-    data['volume_rank'] = data['volumefrom'].rank(pct=True)
+    data['volume_rank'] = data['volume'].rank(pct=True)
     to_roll =  data[['high_rank','volume_rank']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
@@ -343,7 +343,7 @@ def alpha_16(data = None, lag = 5, **kwargs):
 
 def alpha_16_ls(data = None, contravariant = 1., up_threshold = 0.8, low_threshold = 0.2, lag = 5, **kwargs):
     data['high_rank'] = data['high'].rank(pct=True)
-    data['volume_rank'] = data['volumefrom'].rank(pct=True)
+    data['volume_rank'] = data['volume'].rank(pct=True)
     to_roll =  data[['high_rank','volume_rank']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
@@ -361,7 +361,7 @@ def alpha_16_ls(data = None, contravariant = 1., up_threshold = 0.8, low_thresho
 
 def alpha_16_lo(data=None, contravariant=1., up_threshold=0.8, lag=5, **kwargs):
     data['high_rank'] = data['high'].rank(pct=True)
-    data['volume_rank'] = data['volumefrom'].rank(pct=True)
+    data['volume_rank'] = data['volume'].rank(pct=True)
     to_roll = data[['high_rank', 'volume_rank']]
     to_roll = to_roll.reset_index(drop=True)
     result_df = roll_corr(to_roll, window=lag)
@@ -373,7 +373,7 @@ def alpha_16_lo(data=None, contravariant=1., up_threshold=0.8, lag=5, **kwargs):
         return np.nan
 
 def alpha_13_lo(data = None, contravariant = -1., up_threshold=0.8, lag = 5,  **kwargs):
-    to_roll =  data[['close','volumefrom']]
+    to_roll =  data[['close','volume']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.dropna()
@@ -387,7 +387,7 @@ def alpha_13_lo(data = None, contravariant = -1., up_threshold=0.8, lag = 5,  **
         return np.nan
 
 def alpha_13_ls(data = None, contravariant = -1., up_threshold=0.8, low_threshold = 0.2, lag = 5,  **kwargs):
-    to_roll =  data[['close','volumefrom']]
+    to_roll =  data[['close','volume']]
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.dropna()
@@ -427,11 +427,11 @@ def volume_weighted_high_low_vol_lo(data = None, vol_threshold = 0.8, up_trend_t
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -452,12 +452,12 @@ def volume_weighted_high_low_vol_lo(data = None, vol_threshold = 0.8, up_trend_t
     # #trend over the all lookback period
     # trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
     # # vol over the all lookback_period
-    # weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+    # weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volume'].sum()
     #
     #
     # #trend over the lagging period
     # trend_lag = ((data['close'][-1]-data['close'][-1])/data['close'][-1])
-    # weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volumefrom'][-1]
+    # weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volume'][-1]
     #
     if vol_rank > vol_threshold:
         if trend_rank > up_trend_threshold:
@@ -475,11 +475,11 @@ def volume_weighted_high_low_vol_ls(data = None, vol_threshold = 0.8, up_trend_t
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -500,12 +500,12 @@ def volume_weighted_high_low_vol_ls(data = None, vol_threshold = 0.8, up_trend_t
     # #trend over the all lookback period
     # trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
     # # vol over the all lookback_period
-    # weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+    # weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volume'].sum()
     #
     #
     # #trend over the lagging period
     # trend_lag = ((data['close'][-1]-data['close'][-1])/data['close'][-1])
-    # weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volumefrom'][-1]
+    # weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volume'][-1]
     #
     if vol_rank > vol_threshold:
         if trend_rank > up_trend_threshold:
@@ -526,11 +526,11 @@ def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume)
     data['aggregated_high'] =  data['aggregated_indice'].map(high)
     data['aggregated_low'] =  data['aggregated_indice'].map(low)
 
@@ -553,12 +553,12 @@ def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2
     #trend over the all lookback period
     trend = ((data['close'].iloc[-1]-data['close'].iloc[0])/data['close'].iloc[0])
     # vol over the all lookback_period
-    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volume'].sum()
 
 
     #trend over the lagging period
     trend_lag = ((data['close'].iloc[-1]-data['close'].iloc[-2])/data['close'].iloc[-2])
-    weighted_volu_hi_low_lag = data['volu_hi_low'].iloc[-1]/ data['volumefrom'].iloc[-1]
+    weighted_volu_hi_low_lag = data['volu_hi_low'].iloc[-1]/ data['volume'].iloc[-1]
 
 
     signal = np.nan
@@ -591,11 +591,11 @@ def volume_slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, lo
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -647,11 +647,11 @@ def volume_slope_lo(data = None, contravariant = -1., up_trend_threshold=0.8, pe
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -702,11 +702,11 @@ def volume_trending_rank_lo(data = None, contravariant = -1., up_trend_threshold
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -750,11 +750,11 @@ def volume_trending_rank_ls(data = None, contravariant = -1., up_trend_threshold
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -797,11 +797,11 @@ def trending_rank_lo_induced(data = None, contravariant = -1., up_trend_threshol
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -841,11 +841,11 @@ def slope_lo_induced(data = None, contravariant = -1., up_trend_threshold=0.8, p
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -896,11 +896,11 @@ def slope_lo_to_ls(data = None, contravariant = -1., up_trend_threshold=0.8, up_
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -975,11 +975,11 @@ def slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, low_trend
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -1031,11 +1031,11 @@ def trending_rank_ls(data = None, contravariant = -1., up_trend_threshold=0.8, l
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -1077,11 +1077,11 @@ def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column =
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
@@ -1119,12 +1119,12 @@ def counting_candles_ls(data= None, low_threshold = 0.3, up_threshold = 0.8, con
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
     close_diff = data.groupby(['aggregated_indice'])['close_diff'].agg('sum')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
     data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff).copy()
@@ -1154,12 +1154,12 @@ def counting_candles_lo(data= None, up_threshold = 0.8, contravariant = -1., lag
     data['aggregated_indice'].loc[all_indices] = all_indices
     data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
     data['aggregated_indice'] = data['aggregated_indice'].astype(int)
-    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    volume = data.groupby(['aggregated_indice'])['volume'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
     close_diff = data.groupby(['aggregated_indice'])['close_diff'].agg('sum')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volume).copy()
     data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
     data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
     data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff).copy()
