@@ -310,7 +310,7 @@ def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, ke
     return kpis_df, data, hr_dic, json_dic
 
 
-def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False, recompute_return=True):
+def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 15e-4 , transaction_cost = True, print_turnover = False, normalization = False, recompute_return=True):
     if normalization:
         #data.signal = (data.signal - data.signal.mean())/data.signal.std(ddof=0)
         data.signal = expanding_zscore(signal_np_array=data.signal.values)
