@@ -1447,24 +1447,32 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         wh['amount_traded_usd_eth'] = wh.traded_eth * wh.avg_eth_price
         wh['amount_traded_usd_btc'] = wh.traded_xbt * wh.avg_btc_price
 
-        x = wh[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
-                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
+        x = wh[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth',
+                'trading_fees_eth_usd', 'funding_fees_eth_usd',
+                'open_eth_cc', 'open_eth_bnc',
+                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt',
+                'trading_fees_xbt_usd', 'funding_fees_xbt_usd',
+                'open_btc_cc', 'open_btc_bnc',
                 'valuation', 'fut_transfer_usdt_amount', 'wallet_balance','pnl',
-                'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
+
+                'slippage_eth_price_cc', 'slippage_eth_cash_cc',
                 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
+
+                'slippage_btc_price_cc', 'slippage_btc_cash_cc',
                 'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']]
 
         x.index = wh.date
         x = x.rename_axis('timestamp')
         x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
+                     'trading_fees_usd_eth', 'funding_fees_usd_eth',
                      'open_eth_cc', 'open_eth_exchange',
                      'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
+                     'trading_fees_usd_btc', 'funding_fees_usd_btc',
                      'open_btc_cc', 'open_btc_exchange',
                      'wallet_amount_usd', 'transfers_usd', 'wallet_binance_balance','pnl',
-                     'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
+                     'slippage_eth_price_cc', 'slippage_eth_cash_cc',
                      'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                     'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
+                     'slippage_btc_price_cc', 'slippage_btc_cash_cc',
                      'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']
 
         x = x.fillna(0).round(decimals=5)
@@ -1493,21 +1501,28 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
         td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
 
-        x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
-                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
+        x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth',
+                'trading_fees_eth_usd', 'funding_fees_eth_usd',
+                'open_eth_cc', 'open_eth_bnc',
+                'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt',
+                'trading_fees_xbt_usd', 'funding_fees_xbt_usd',
+                'open_btc_cc', 'open_btc_bnc',
                 'valuation', 'fut_transfer_usdt_amount','wallet_balance','pnl',
-                'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
+                'slippage_eth_price_cc', 'slippage_eth_cash_cc',
+                'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
         x.index = td.date
         x = x.rename_axis('timestamp')
         x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
+                     'trading_fees_usd_eth', 'funding_fees_usd_eth',
                      'open_eth_cc', 'open_eth_exchange',
                      'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
+                     'trading_fees_usd_btc', 'funding_fees_usd_btc',
                      'open_btc_cc', 'open_btc_exchange',
                      'wallet_amount_usd', 'transfers_usd','wallet_binance_balance','pnl',
-                     'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                     'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
+                     'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
+                     'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]
 
         x = x.fillna(0).round(decimals=5)
 
