@@ -307,29 +307,6 @@ def trades_to_arr(df):
     return df.astype(float).values, d
 
 
-def trades_to_arr(df):
-    # Buy = 1
-    # Sell = -1
-    # XBT = 1
-    # ETH = -1
-    # Market = 1
-    # Limit = 0
-    # Funding = 0
-    # Limit = 1
-    from numba import typed
-    df = df.replace('Buy', 1).replace('Sell', -1).replace('ETHUSD', -1).replace('XBTUSD', 1).replace('Limit',
-                                                                                                     0).replace(
-        'Market', 1).replace('Trade', 1).replace('Funding', 0)
-    df = df[['symbol', 'side', 'lastQty', 'lastPx', 'orderQty', 'price', 'execType', 'ordType', 'leavesQty', 'cumQty',
-             'avgPx', 'commission', 'execCost', 'execComm', 'homeNotional', 'foreignNotional', 'transactTime']].copy()
-    df.transactTime = df.transactTime.apply(lambda x: x.timestamp() * 1000)
-    df = df.replace(np.nan, 0)
-    df = df.replace({'(.*?)': 0}, regex=True)
-    d = typed.Dict()
-    for i, k in enumerate(df.columns):
-        d[k] = i
-    return df.astype(float).values, d
-
 
 @jit(nopython=True)
 def find_lastPx(arr, d):
@@ -524,6 +501,23 @@ def get_fees(arr, d):
             fold_a.append(np.array(_))
         return fold_a
 
+
+def preprocess_bitmex_trades_xbt(trades_df):
+    trades_df = trades_df[['symbol', 'side', 'lastQty', 'lastPx', 'orderQty', 'price', 'execType', 'ordType', 'leavesQty', 'cumQty',
+             'avgPx', 'commission', 'execCost', 'execComm', 'homeNotional', 'foreignNotional', 'transactTime']].copy()
+    trades_df.transactTime = trades_df.transactTime.apply(lambda x: x.timestamp() * 1000)
+
+    execs_df = trades_df[trades_df['execType'] == 'Trade'].copy()
+    fundings_df = trades_df[trades_df['execType'] == 'Funding'].copy()
+
+    execs_df['contracts_quantity'] = execs_df['lastQty']
+    fundings_df['contracts_quantity'] = fundings_df['lastQty']
+
+    execs_df['fees_xbt'] = execs_df['execComm']/100000000
+    fundings_df['fees_xbt'] = fundings_df['lastQty']/100000000
+
+    return execs_df, fundings_df
+
 def preprocess_bitmex_trades(trades):
     df, d = trades_to_arr(trades)
     df, d = numba_compute(df, d)
@@ -608,6 +602,418 @@ def cryptocompare_get(ssj ='USDT',ssj_against='USD', daily_crypto_starting_day=N
     print(dataframe.shape)
     return dataframe
 
+
+def fetch_all_necessary_data_b40_xbt(public_key = None, private_key= None, start_time= None, end_time= None, me_month=None, save_to_dropbox = False, dropbox_token = None, local_root_directory ='./', recompute_all = True, by_pass_month = False):
+
+    dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
+
+    start_time_stub = start_time.strftime('%d_%b_%Y')
+    end_time_stub = end_time.strftime('%d_%b_%Y')
+    filename_stub = f'{public_key}_{start_time_stub}_{end_time_stub}_Bitmex'
+    #filename_stub = f'{inv_year_dictionary[year]}_{inv_month_dictionary[month]}_{inv_market_dictionary[market]}'
+
+
+    reportvalo_pkl_file_name = f'{filename_stub}_report_valo_b40.pkl'
+    trade_pkl_file_name = f'{filename_stub}_trades_b40.pkl'
+    processed_trade_pkl_file_name = f'{filename_stub}_processed_trades_b40.pkl'
+    processed_funding_pkl_file_name = f'{filename_stub}_processed_funding_b40.pkl'
+
+    positions_pkl_file_name = f'{filename_stub}_positions_b40.pkl'
+
+    ohlc_btc_cc_pkl_file_name = f'{filename_stub}_ohlc_btc_cc.pkl'
+
+    ohlc_usdt_day_cc_pkl_file_name = f'{filename_stub}_ohlc_usdt_day_cc.pkl'
+
+    if recompute_all:
+        ohlc_usdt_day_cc = cryptocompare_get(ssj ='USDT', ssj_against='USD', daily_crypto_starting_day=start_time, daily_crypto_ending_day=end_time, aggreg ='1d')
+
+        client = bitmex.bitmex(test=False, config=None, api_key=public_key, api_secret=private_key)
+
+        #getting all the wallet information
+        #wallet_valo_histo = pd.DataFrame(client.User.User_getWalletHistory().result()[0])
+        actual_positions = pd.DataFrame(client.Position.Position_get().result()[0])
+
+        if isinstance(start_time,dt.datetime) and isinstance(end_time,dt.datetime):
+            start_time = start_time.strftime('%Y-%m-%dT%H:%M')
+            end_time = end_time.strftime('%Y-%m-%dT%H:%M')
+
+        ce, te = parser.parse(start_time).replace(tzinfo=pytz.UTC), parser.parse(end_time).replace(tzinfo=pytz.UTC)
+
+        ce = ce - dt.timedelta(hours=8)
+        trades = pd.DataFrame()
+        print('Accessing Trade History...')
+        previous_ce = None
+        while ce < te:
+            print(f'requesting trades between {ce} and {te}')
+            previous_ce = ce
+            tmp = pd.DataFrame(client.Execution.Execution_getTradeHistory(startTime=ce, count=500).result()[0]).sort_values(
+                by='timestamp', ascending=True)
+            trades = trades.append(tmp)
+            time.sleep(4)
+            ce = tmp.timestamp.iloc[-1]
+            if ce == previous_ce:
+                break
+        trades = trades[trades.timestamp <= te].copy()
+        trades.execComm = - trades.execComm  # logique comptable
+        trades = trades.sort_values(by='timestamp', ascending=True).drop_duplicates()
+        print('Done trades.')
+
+        # Get wallet history for a period of time
+        ce, te = parser.parse(start_time).replace(tzinfo=pytz.UTC), parser.parse(end_time).replace(tzinfo=pytz.UTC)
+        ce = ce - dt.timedelta(hours=8)
+        walletHist = pd.DataFrame()
+        print('Accessing wallet history...')
+        previous_ce = None
+        while ce < te:
+            print(f'requesting wallet history between {ce} and {te}')
+            previous_ce = ce
+            tmp = pd.DataFrame(client.User.User_getWalletHistory(currency='XBt').result()[0]).sort_values(by='timestamp',
+                                                                                                          ascending=True)
+            walletHist = walletHist.append(tmp)
+            time.sleep(3.5)
+            ce = tmp.timestamp.iloc[-1]
+            if ce == previous_ce:
+                break
+        walletHist = walletHist[walletHist.timestamp <= te].copy()
+        print('Wallet History retrieved.')
+
+        # Récupérer les OHLC hourly sur Cryptocompare depuis startdate
+        cc = CryptoCompare('')
+        ohlc_btc_cc = cc.get('OHLC', 'BTC', start_time, end_time, precision='hour')
+
+        if save_to_dropbox :
+            full_path = local_root_directory + trade_pkl_file_name
+            trades.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=trade_pkl_file_name, overwrite=True)
+            #os.remove(full_path)
+
+            full_path = local_root_directory + reportvalo_pkl_file_name
+            walletHist.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=reportvalo_pkl_file_name, overwrite=True)
+            #os.remove(full_path)
+
+            full_path = local_root_directory + ohlc_btc_cc_pkl_file_name
+            ohlc_btc_cc.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=ohlc_btc_cc_pkl_file_name, overwrite=True)
+            #os.remove(full_path)
+
+            full_path = local_root_directory + positions_pkl_file_name
+            actual_positions.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=positions_pkl_file_name, overwrite=True)
+            #os.remove(full_path)
+
+            full_path = local_root_directory + ohlc_usdt_day_cc_pkl_file_name
+            ohlc_usdt_day_cc.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=ohlc_usdt_day_cc_pkl_file_name, overwrite=True)
+            #            os.remove(full_path)
+    else:
+        # trades=dbx.download_pkl(trade_pkl_file_name)
+        # walletHist=dbx.download_pkl(reportvalo_pkl_file_name)
+        # ohlc_btc_cc=dbx.download_pkl(ohlc_btc_cc_pkl_file_name)
+        # actual_positions=dbx.download_pkl(positions_pkl_file_name)
+
+
+        ohlc_usdt_day_cc = pd.read_pickle(local_root_directory+ohlc_usdt_day_cc_pkl_file_name)
+        trades=pd.read_pickle(local_root_directory +trade_pkl_file_name)
+        walletHist=pd.read_pickle(local_root_directory +reportvalo_pkl_file_name)
+        ohlc_btc_cc=pd.read_pickle(local_root_directory +ohlc_btc_cc_pkl_file_name)
+        actual_positions=pd.read_pickle(local_root_directory +positions_pkl_file_name)
+    ##############################
+    ##############################
+    ##########
+    ########## computing positions
+    ##########
+    ##############################
+    ##############################
+    print('usdt change rate fetched')
+    print(ohlc_usdt_day_cc.shape)
+
+    print(actual_positions.shape)
+    if not actual_positions.empty:
+        actual_positions.timestamp = actual_positions.timestamp.apply(lambda x: x.timestamp() * 1000)
+        actual_positions['timestamp'] = pd.to_datetime(actual_positions['timestamp'],unit='ms')
+        actual_positions['totalAsset']=actual_positions['currentQty']/actual_positions['lastPrice']
+        posColumns=[
+            'timestamp',
+            'symbol',
+            'lastPrice',
+            'totalAsset'
+        ]
+        actual_positions = actual_positions[posColumns].copy()
+        actualPositions = actual_positions.rename(columns={
+            'symbol':'asset',
+            'totalAsset':'amount',
+            'lastPrice':'price'
+        })
+
+        print('done')
+
+    ##############################
+    ##############################
+    ##########
+    ########## computing trades
+    ##########
+    ##############################
+    ##############################
+    reprocess_numba_trades = True
+    if reprocess_numba_trades:
+        print(f'size before dropping duplicates {trades.shape}')
+        trades = trades.sort_values(by='timestamp', ascending=True).drop_duplicates()
+        print(f'size before dropping duplicates {trades.shape}')
+
+        print('preprocessing trades')
+        execs_df, funding_df = preprocess_bitmex_trades_xbt(trades.copy())
+
+        # laetitia numba version
+        #bitmex_df = preprocess_bitmex_trades(trades)
+
+        print('preporcessing done')
+        print(execs_df.shape)
+        if save_to_dropbox:
+            full_path = local_root_directory + processed_trade_pkl_file_name
+            execs_df.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=processed_trade_pkl_file_name, overwrite=True)
+            #            os.remove(full_path)
+
+            full_path = local_root_directory + processed_funding_pkl_file_name
+            funding_df.to_pickle(full_path)
+            print(f'uploading to dropbox {full_path}')
+            dbx.upload(fullname=full_path, folder='', subfolder='', name=processed_funding_pkl_file_name, overwrite=True)
+            #            os.remove(full_path)
+
+    else:
+        execs_df=pd.read_pickle(local_root_directory +processed_trade_pkl_file_name)
+        funding_df=pd.read_pickle(local_root_directory +processed_funding_pkl_file_name)
+
+
+    ##############################
+    ##############################
+    ##########
+    ########## computing valos
+    ##########
+    ##############################
+    ##############################
+    # ohlc_btc_cc
+    x = ohlc_btc_cc.copy()
+    x.index = x.index.map(parser.parse)
+    x.index = x.index.tz_localize(None)
+    x.columns = [y + '_btc_cc' for y in x.columns]
+    ohlc_btc_cc = x.copy()
+
+    walletHist = walletHist.set_index('timestamp')
+    walletHist.index = walletHist.index.map(lambda x: x.floor('60s'))
+    walletHist = walletHist[~walletHist.index.duplicated(keep='first')].sort_index(ascending=True)
+    walletHist.index = walletHist.index.tz_localize(None)
+
+
+    walletHist['walletBalance_xbt'] = walletHist.walletBalance / 100000000
+
+
+    def compute_signal_effective_date(row):
+        # if np.isnan(row['date']):
+        if pd.isnull(row['date']):
+            return np.nan
+        else:
+            return (datetime.date(row['date'].year, row['date'].month, row['date'].day)) #+timedelta(days = 1))
+
+    walletHist['date'] = pd.to_datetime(walletHist.index)
+    walletHist['date'] = walletHist.apply(compute_signal_effective_date, axis=1)
+    walletHist.index = walletHist['date']
+#    walletHist = pd.merge(walletHist, ohlc_usdt_day_cc, left_index = True, right_index = True)
+    walletHist = pd.merge(walletHist, ohlc_btc_cc['close_btc_cc'], left_index=True, right_index=True)
+    #walletHist['open_btc_cc'] = walletHist['open_btc_cc'].bfill()
+
+    walletHist['walletBalance_usd'] = walletHist.walletBalance_xbt * walletHist.close_btc_cc
+    ########################################################################
+    ########################################################################
+    ################### gettingn the proper trades df
+
+    execs_df = execs_df.rename(columns={
+        'symbol': 'Security Code',
+        'side': 'Oper',
+        'contracts_quantity': 'Amount',
+        'price': 'Price',
+        'fees_xbt': 'Fees',
+        'transactTime': 'Date'
+    })
+
+    funding_df = funding_df.rename(columns={
+        'symbol': 'Security Code',
+        'side': 'Oper',
+        'contracts_quantity': 'Amount',
+        'price': 'Price',
+        'fees_xbt': 'Fees',
+        'transactTime': 'Date'
+    })
+    execs_df['Date'] = pd.to_datetime(execs_df['Date'], unit='ms')
+    funding_df['Date'] = pd.to_datetime(funding_df['Date'], unit='ms')
+
+    bitmex_df =execs_df.copy()
+
+    bitmex_df['Nature'] = 'CRY'
+    bitmex_df['Currency'] = 'USD'
+
+    funding_df['Nature'] = 'CRY'
+    funding_df['Currency'] = 'USD'
+
+    trades_columns = ['Nature', 'Security Code', 'Currency', 'Oper', 'Date', 'Amount','Price', 'Fees']
+
+    bitmex_df = bitmex_df[trades_columns].copy()
+    funding_df = funding_df[trades_columns].copy()
+
+
+    def convert_symbol(row):
+        if row['Security Code'] == 'XBTUSD':
+            return 'BTC'
+        elif row['Security Code'] == 'ETHUSD':
+            return 'Ethereum'
+        else:
+            return np.nan
+
+    bitmex_df['Security Code'] = bitmex_df.apply(convert_symbol, axis=1)
+
+
+    def filter_me_month(data_df, filtering_month):
+        data_df['month'] = data_df['Date'].dt.month
+        data_df['insideMonth'] = data_df['month'] == filtering_month
+        data_df = data_df[data_df['insideMonth']].copy()
+        data_df = data_df.drop(columns=['month', 'insideMonth'])
+        return data_df
+
+    if not by_pass_month:
+        filtered_bitmex_df=filter_me_month(bitmex_df.copy(),me_month)
+        funding_df=filter_me_month(funding_df.copy(),me_month)
+
+    ############## getting the proper wallet Hist
+    filteredWallet = walletHist.copy()
+    filteredWallet['Date'] = filteredWallet.index
+    filteredWallet['month'] = filteredWallet['Date'].dt.month
+    filteredWallet['insideMonth'] = filteredWallet['month'] == me_month
+    filteredWallet['shiftedInsideMonth'] = filteredWallet['insideMonth'].shift(-1)
+    filteredWallet['shiftedInsideMonth'] = filteredWallet['shiftedInsideMonth'].fillna(True)
+    filteredWallet = filteredWallet[filteredWallet['shiftedInsideMonth']].copy()
+    filteredWallet = filteredWallet.drop(columns=['month', 'insideMonth', 'shiftedInsideMonth'])
+
+    filteredWallet = filteredWallet.iloc[[0, -1]]
+
+    if by_pass_month:
+        minDate = min(walletHist.index)
+        maxDate = max(walletHist.index)
+
+        filtered_bitmex_df = bitmex_df[bitmex_df['Date'] >= minDate].copy()
+        filtered_bitmex_df = filtered_bitmex_df[filtered_bitmex_df['Date'] <= maxDate].copy()
+
+        walletHist_df = walletHist[walletHist.index >= minDate].copy()
+        walletHist_df = walletHist_df[walletHist_df.index <= maxDate].copy()
+    else :
+        walletHist_df = walletHist.copy()
+    walletHist_df['Date'] = walletHist_df.index
+
+    walletHist_df = walletHist_df.sort_values(by = 'Date')
+    #######
+
+
+    filtered_bitmex_df = filtered_bitmex_df.sort_values(by = 'Date')
+    valo_columns=[
+        'close_btc_cc',
+        #'close',
+        'walletBalance_xbt',
+        'walletBalance_usd',
+        'Date'
+    ]
+    #assert(filtered_bitmex_df['Value'].sum() == walletHist_df['realizedPnl'].sum())
+    walletHist_df['Date'] = walletHist_df.index
+
+    filteredWallet = filteredWallet[valo_columns].copy()
+
+    filteredWallet = filteredWallet.rename(columns = {
+        'walletBalance_xbt':'wallet_balance_btc',
+        'walletBalance_usd': 'wallet_balance_usd',
+        'close_btc_cc':'btc_price',
+      #  'close':'rate_usdt_usd'
+    })
+
+    walletHist_df = walletHist_df.rename(columns = {
+        'walletBalance_xbt':'wallet_balance_btc',
+        'walletBalance_usd': 'wallet_balance_usd',
+        'close_btc_cc':'btc_price',
+      #  'close':'rate_usdt_usd'
+    })
+
+    valo_columns=[
+        'Date',
+        'btc_price',
+        'wallet_balance_usd',
+        'wallet_balance_btc',
+        #'rate_usdt_usd'
+    ]
+
+    b40_cols = ['Nature', 'Security Code', 'Currency', 'Description', 'Comment', 'Oper', 'Date', 'Value', 'Settlement',
+                'Amount', 'Price', 'Int. Rate', 'Meth', 'Excl', 'Last Coupon', 'Interest', 'Depo', 'Bank', 'Pmt Cur',
+                'Source',	'Investor', 'Fees', 'Bank']
+    for me_col in b40_cols:
+        if me_col not in filtered_bitmex_df.columns:
+            filtered_bitmex_df[me_col] = np.nan
+
+    filtered_bitmex_df = filtered_bitmex_df[b40_cols].copy()
+    filWal = filteredWallet[valo_columns].copy()
+    wal =  walletHist_df[valo_columns]
+
+    filtered_bitmex_df = filtered_bitmex_df.sort_values(by=['Date'])
+    filWal = filWal.sort_values(by=['Date'])
+    wal = wal.sort_values(by=['Date'])
+
+    filtered_bitmex_df['Date'] = filtered_bitmex_df['Date'].dt.strftime('%d/%m/%Y')
+
+    filtered_bitmex_df['Value'] = filtered_bitmex_df['Date']
+    filtered_bitmex_df['Settlement'] = filtered_bitmex_df['Date']
+
+    filtered_bitmex_df['Depo'] = 'BIM'
+    filtered_bitmex_df['Bank'] = 'BIM'
+
+    filtered_bitmex_df['Pmt Cur'] = 'BTC'
+    filtered_bitmex_df['Source'] = 'Manual'
+
+    filtered_bitmex_df.iloc[:,len(filtered_bitmex_df.columns)-1]=''
+
+
+    funding_df['Date'] = funding_df['Date'].dt.strftime('%d/%m/%Y')
+
+    funding_df['Value'] = funding_df['Date']
+    funding_df['Settlement'] = funding_df['Date']
+
+    funding_df['Depo'] = 'BIM'
+    funding_df['Bank'] = 'BIM'
+
+    funding_df['Pmt Cur'] = 'BTC'
+    funding_df['Source'] = 'Manual'
+
+    def convert_side(row):
+        if row['Oper'] == 'Sell':
+            return 'SEL'
+        elif row['Oper'] == 'Buy':
+            return 'BUY'
+        else:
+            return np.nan
+
+    filtered_bitmex_df['Oper'] = filtered_bitmex_df.apply(convert_side, axis=1)
+
+    filtered_bitmex_df['Amount'] = filtered_bitmex_df['Amount'] /filtered_bitmex_df['Price']
+
+    summary_df = filtered_bitmex_df.groupby(['Security Code', 'Oper'])['Amount'].sum()
+
+    summary_df = summary_df.reset_index()
+
+    return filtered_bitmex_df,filWal,wal,actual_positions, funding_df, summary_df
+
+
+
 def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_time= None, end_time= None, me_month=None, save_to_dropbox = False, dropbox_token = None, local_root_directory ='./', recompute_all = True, by_pass_month = False):
 
     dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
